@@ -2,23 +2,35 @@ import os
 import yaml
 import logging
 import subprocess
+import requests
 from jinja2 import Environment, PackageLoader
 from hedera import Client, AccountId, PrivateKey, Hbar, FileCreateTransaction, FileContentsQuery, FileId, FileAppendTransaction, FileInfoQuery
 
 OPERATOR_ID= AccountId.fromString(os.environ["OPERATOR_ID"])
 OPERATOR_PRIVATE_KEY= PrivateKey.fromString(os.environ["OPERATOR_PRIVATE_KEY"])
-FILEID=os.environ["FILEID"]
+INTENTID=os.environ["INTENTID"]
+APIKEY=os.environ["APIKEY"]
 
 class network3_perseus():
-    def __init__(self):
-        self.fileId=FILEID
-
     def configure_device(self):
+        self.get_file_id_from_dragonglass()
         self.get_file_from_hedera()
-        # self.add_file_to_hedera()
-        # self.pre_change=self.capture_pre_state()
-        # self.push_config(self.yaml_contents)
-        # self.post_change=self.capture_post_state()
+        self.add_file_to_hedera()
+        self.pre_change=self.capture_pre_state()
+        self.push_config(self.yaml_contents)
+        self.post_change=self.capture_post_state()
+
+    def get_file_id_from_dragonglass(self):
+        url = f"https://api-testnet.dragonglass.me/hedera/api/accounts/{ INTENTID }/files"
+        payload = {}
+        headers = {
+            'X-API-KEY': f'{ APIKEY }',
+            'accept': 'application/json'
+        }
+        response = requests.request("GET", url, headers=headers, data = payload, verify=False)
+        json_response = response.json()
+        self.fileId=json_response['data'][0]['fileID']
+        print(self.fileId)
 
     def get_file_from_hedera(self):
         client = Client.forTestnet()
@@ -26,13 +38,7 @@ class network3_perseus():
         query = FileContentsQuery()
         hedera_fileId = FileId.fromString(self.fileId)
         contents = query.setFileId(hedera_fileId).execute(client)
-        all_yaml = yaml.safe_load(contents.toStringUtf8())
-        items=[]
-        for item, value in all_yaml.items():
-            items.append(item)
-            latest_intent = max(items)
-        print(all_yaml[latest_intent])
-            #self.yaml_contents = value
+        self.yaml_contents = yaml.safe_load(contents.toStringUtf8())
 
     def capture_pre_state(self):
         command="show running-config"
